@@ -296,7 +296,8 @@ static int defineSolver(const std::string &name)
 #endif
 
 int MergeFile(const std::string &fileName, bool warnIfMissing,
-              bool setBoundingBox, bool importPhysicalsInOnelab)
+              bool setBoundingBox, bool importPhysicalsInOnelab,
+              int partitionToRead)
 {
   // added 'b' for pure Windows programs, since some of these files
   // contain binary data
@@ -438,9 +439,6 @@ int MergeFile(const std::string &fileName, bool warnIfMissing,
     status = GModel::current()->readP3D(fileName);
     mesh = true;
   }
-  else if(ext == ".fm" || ext == ".FM") {
-    status = GModel::current()->readFourier(fileName);
-  }
 #if defined(HAVE_FLTK)
   else if(ext == ".pnm" || ext == ".PNM" || ext == ".pbm" || ext == ".PBM" ||
           ext == ".pgm" || ext == ".PGM" || ext == ".ppm" || ext == ".PPM") {
@@ -520,7 +518,7 @@ int MergeFile(const std::string &fileName, bool warnIfMissing,
       }
       mesh = true;
 #if defined(HAVE_POST)
-      if(status > 1) status = PView::readMSH(fileName);
+      if(status > 1) status = PView::readMSH(fileName, -1, partitionToRead);
 #endif
     }
 #if defined(HAVE_POST)
