@@ -147,9 +147,9 @@ public:
   void drawString(const char *str) { gl_draw(str); }
   void resetFontTextures()
   {
-#if defined(__APPLE__)
-    gl_texture_pile_height(
-      gl_texture_pile_height()); // force font texture recomputation
+#if ((FL_MAJOR_VERSION == 1) && (FL_MINOR_VERSION >= 4)) || defined(__APPLE__)
+    // force font texture recomputation
+    gl_texture_pile_height(gl_texture_pile_height());
 #endif
   }
   std::string getName() { return "Fltk"; }
