@@ -20,7 +20,6 @@
 
 template <class scalar> class simpleFunction;
 
-class FM_Internals;
 class GEO_Internals;
 class OCC_Internals;
 class ACIS_Internals;
@@ -107,8 +106,6 @@ protected:
   OCC_Internals *_occ_internals;
   // ACIS model internal data
   ACIS_Internals *_acis_internals;
-  // Fourier model internal data
-  FM_Internals *_fm_internals;
 
   // characteristic length (mesh size) fields
   FieldManager *_fields;
@@ -147,9 +144,6 @@ protected:
 
   void _deleteACISInternals();
 
-  void _createFMInternals();
-  void _deleteFMInternals();
-
   // CGNS helpers
   int _readCGNSStructured(const std::string &name);
   int _readCGNSUnstructured(const std::string &name);
@@ -255,7 +249,6 @@ public:
   GEO_Internals *getGEOInternals() { return _geo_internals; }
   void createOCCInternals();
   OCC_Internals *getOCCInternals() { return _occ_internals; }
-  FM_Internals *getFMInternals() { return _fm_internals; }
   ACIS_Internals *getACISInternals() { return _acis_internals; }
 
   // access characteristic length (mesh size) fields
@@ -629,11 +622,6 @@ public:
                bool onlyPhysicals = false);
   int exportDiscreteGEOInternals();
 
-  // Fourier model
-  int readFourier();
-  int readFourier(const std::string &name);
-  int writeFourier(const std::string &name);
-
   // OCC model
   int readOCCBREP(const std::string &name);
   int readOCCSTEP(const std::string &name);
