@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #include <stdlib.h>
 #include <queue>
@@ -108,6 +108,8 @@ int discreteFace::trianglePosition(double par1, double par2, double &u,
                                    double &v) const
 {
 #if defined(HAVE_HXT)
+  if(_parametrizations.empty()) return 0;
+
   double xy[3] = {par1, par2, 0};
   double uv[3];
   const MElement *e =
@@ -127,6 +129,8 @@ int discreteFace::trianglePosition(double par1, double par2, double &u,
 GPoint discreteFace::point(double par1, double par2) const
 {
 #if defined(HAVE_HXT)
+  if(_parametrizations.empty()) return 0;
+
   double xy[3] = {par1, par2, 0};
   double uv[3];
   const MElement *e =
@@ -217,6 +221,8 @@ GPoint discreteFace::closestPoint(const SPoint3 &queryPoint, double maxDistance,
                                   SVector3 *normal) const
 {
 #if defined(HAVE_HXT)
+  if(_parametrizations.empty()) return GPoint();
+
   dfWrapper wrapper(queryPoint);
   do {
     wrapper._distance = 1.e22;
@@ -285,6 +291,8 @@ SPoint2 discreteFace::parFromPoint(const SPoint3 &p, bool onSurface) const
 SVector3 discreteFace::normal(const SPoint2 &param) const
 {
 #if defined(HAVE_HXT)
+  if(_parametrizations.empty()) return SVector3();
+
   MElement *e = _parametrizations[_current_parametrization].oct->find(
     param.x(), param.y(), 0.0);
   if(!e) {
@@ -315,6 +323,9 @@ double discreteFace::curvatures(const SPoint2 &param, SVector3 &dirMax,
 Pair<SVector3, SVector3> discreteFace::firstDer(const SPoint2 &param) const
 {
 #if defined(HAVE_HXT)
+  if(_parametrizations.empty())
+    return Pair<SVector3, SVector3>(SVector3(), SVector3());
+
   MElement *e = _parametrizations[_current_parametrization].oct->find(
     param.x(), param.y(), 0.0);
   if(!e) {
@@ -359,11 +370,9 @@ Pair<SVector3, SVector3> discreteFace::firstDer(const SPoint2 &param) const
 
   return Pair<SVector3, SVector3>(SVector3(dxdu[0][0], dxdu[1][0], dxdu[2][0]),
                                   SVector3(dxdu[0][1], dxdu[1][1], dxdu[2][1]));
-
 #endif
-  SVector3 v;
   Msg::Error("firstDer failed");
-  return Pair<SVector3, SVector3>(v, v);
+  return Pair<SVector3, SVector3>(SVector3(), SVector3());
 }
 
 void discreteFace::secondDer(const SPoint2 &param, SVector3 &dudu,
@@ -674,6 +683,8 @@ GPoint discreteFace::intersectionWithCircle(const SVector3 &n1,
                                             double uv[2])
 {
 #if defined(HAVE_HXT)
+  if(_parametrizations.empty()) return GPoint();
+
   MTriangle *t2d =
     (MTriangle *)_parametrizations[_current_parametrization].oct->find(
       uv[0], uv[1], 0.0);
@@ -991,7 +1002,8 @@ bool discreteFace::compute_topology_of_partition(
             //	   vs[i]->onWhat()->mesh_vertices.end());
             discreteEdge *de = static_cast<discreteEdge *>(vs[i]->onWhat());
             if(!de) Msg::Error("Can only split discrete edges at that point");
-            discreteVertex *gstart = new discreteVertex(gm, ++TAG + 1);
+            discreteVertex *gstart = new discreteVertex
+              (gm, ++TAG + 1, vs[i]->x(), vs[i]->y(), vs[i]->z());
             gm->add(gstart);
             vs[i]->setEntity(gstart);
             gstart->mesh_vertices.push_back(vs[i]);
@@ -1020,7 +1032,8 @@ bool discreteFace::compute_topology_of_partition(
         if(ends[0]->onWhat() == this || ends[1]->onWhat() == this) {
           for(int i = 0; i < 2; i++) {
             if(ends[i]->onWhat() == this) {
-              discreteVertex *gstart = new discreteVertex(gm, ++TAG);
+              discreteVertex *gstart = new discreteVertex
+                (gm, ++TAG, ends[i]->x(), ends[i]->y(), ends[i]->z());
               v_internals.push_back(gstart);
               gm->add(gstart);
               ends[i]->setEntity(gstart);
@@ -1070,7 +1083,8 @@ bool discreteFace::compute_topology_of_partition(
           //    (std::remove(ends[k]->onWhat()->mesh_vertices.begin(),
 	  //	 ends[k]->onWhat()->mesh_vertices.end(), ends[k]),
 	  //	 ends[k]->onWhat()->mesh_vertices.end());
-	  gends[k] = new discreteVertex (gm, ++TAG);
+	  gends[k] = new discreteVertex
+            (gm, ++TAG, ends[k]->x(), ends[k]->y(), ends[k]->z());
 	  v_internals.push_back(gends[k]);
 	  gm->add(gends[k]);
 	  ends[k]->setEntity(gends[k]);
@@ -1084,7 +1098,8 @@ bool discreteFace::compute_topology_of_partition(
 	    //	 ends[k]->onWhat()->mesh_vertices.end());
 	    discreteEdge *de = static_cast<discreteEdge*> (ends[k]->onWhat());
 	    if (!de)Msg::Error("can only split discrete edges at that point");
-	    gends[k] = new discreteVertex (gm, ++TAG);
+	    gends[k] = new discreteVertex
+              (gm, ++TAG, ends[k]->x(), ends[k]->y(), ends[k]->z());
 	    gm->add(gends[k]);
 	    ends[k]->setEntity(gends[k]);
 	    gends[k]->mesh_vertices.push_back(ends[k]);
